#!/usr/bin/perl
#
# $Id: migrate_hosts.pl,v 1.5 2003/04/15 03:09:34 lukeh Exp $
#
# Copyright (c) 1997-2003 Luke Howard.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
#        This product includes software developed by Luke Howard.
# 4. The name of the other may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE LUKE HOWARD ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL LUKE HOWARD BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
#
# hosts migration tool
#
#

require '/usr/share/migrationtools/migrate_common.ph';

$PROGRAM = "migrate_hosts.pl";
$NAMINGCONTEXT = &getsuffix($PROGRAM);

&parse_args();
&open_files();

while(<INFILE>)
{
	chop;
	next unless ($_);
	next if /^#/;
	s/#(.*)$//;
	local($hostaddr, $hostname, @aliases) = split(/\s+/);
	&add_host($hostaddr, $hostname, @aliases)
}

if ($use_stdout) {
	&dump_hosts(STDOUT);
} else {
	&dump_hosts(OUTFILE);
}

# hash hostname -> IPaddresses
%hosts={};

sub add_host
{
	local($hostaddr, $hostname, @aliases) = @_;
	return if (!$hostaddr);
	
	if ($hosts{$hostname}) {
		@addrs = @{$hosts{$hostname}};
		push(@addrs, $hostaddr);
		$hosts{$hostname} = [@addrs];
	} else {
		$hosts{$hostname} = [$hostaddr];
	}

	foreach (@aliases) {
		if ($hosts{$_}) {
			@addrs = @{$hosts{$_}};
			push(@addrs, $hostaddr);
		} else {
			@hosts{$_} = [$hostaddr];
		}
	}
}

sub dump_hosts
{
	my $HANDLE = shift;
	for my $hostname ( keys %hosts ) {
		print $HANDLE "dn: cn=$hostname,$NAMINGCONTEXT\n";
		print $HANDLE "cn: $hostname\n";
		print $HANDLE "objectClass: top\n";
		print $HANDLE "objectClass: ipHost\n";
		print $HANDLE "objectClass: device\n";
		@addrs = @{$hosts{$hostname}};
		for my $hostaddr (@addrs) {
			print $HANDLE "ipHostNumber: $hostaddr\n";
		}
		print $HANDLE "\n";
	}
}

close(INFILE);
if (OUTFILE != STDOUT) { close(OUTFILE); }

